Index: src/Graph/AdjacencyList.cpp
===================================================================
--- src/Graph/AdjacencyList.cpp	(revision 0fad93db3291c128f999fcbf427d65f1824b785b)
+++ src/Graph/AdjacencyList.cpp	(revision 5197e543aadb7e0a5343495b6e246005819cd457)
@@ -58,5 +58,5 @@
   NonMatchNumber(0)
 {
-  bool status = ParseInInternalMap(File);
+  bool status = ParseIntoMap(File, InternalAtomBondMap);
   if (!status) // remove map if failed to parse
     InternalAtomBondMap.clear();
@@ -66,10 +66,11 @@
 {}
 
-/** Parses the bond partners of each atom from an external file into \a AtomBondMap.
+/** Parses the bond partners of each atom from an external file into \a atombondmap.
  *
  * @param File file to parse
+ * @param &atombondmap map to parse into
  * @return true - everything ok, false - error while parsing
  */
-bool AdjacencyList::ParseInInternalMap(std::istream &File)
+bool AdjacencyList::ParseIntoMap(std::istream &File, AtomBondMap &atombondmap)
 {
   if (File.fail()) {
@@ -78,5 +79,5 @@
   }
 
-  InternalAtomBondMap.clear();
+  atombondmap.clear();
   char buffer[MAXSTRINGSIZE];
   int tmp;
@@ -97,5 +98,5 @@
       while (line >> ws >> tmp) {
         LOG(3, "INFO: Recognized bond partner " << tmp-1 << " for " << WalkerId << ".");
-        InternalAtomBondMap.insert( std::make_pair(WalkerId, tmp-1) );
+        atombondmap.insert( std::make_pair(WalkerId, tmp-1) );
       }
     } else {
@@ -111,17 +112,18 @@
 /** Fills the InternalAtomBondMap from the atoms given by the two iterators.
  *
+ * @param &atombondmap map to create
  * @param atomids set of atomic ids to check (must be global ids, i.e. from atom::getId())
  */
-void AdjacencyList::CreateExternalMap(const atomids_t &atomids)
-{
-  ExternalAtomBondMap.clear();
+void AdjacencyList::CreateMap(const atomids_t &atomids, AtomBondMap &atombondmap)
+{
+  atombondmap.clear();
   // go through each atom in the list
   for (atomids_t::const_iterator iter = atomids.begin(); iter != atomids.end(); ++iter) {
     const atomId_t WalkerId = *iter;
     ASSERT(WalkerId != (size_t)-1,
-        "AdjacencyList::CreateExternalMap() - Walker has no id.");
+        "AdjacencyList::CreateMap() - Walker has no id.");
     const atom *Walker = World::getInstance().getAtom(AtomById(WalkerId));
     ASSERT( Walker != NULL,
-        "AdjacencyList::CreateExternalMap() - Walker id "+toString(*iter)
+        "AdjacencyList::CreateMap() - Walker id "+toString(*iter)
         +" is not associated to any of World's atoms.");
     const BondList& ListOfBonds = Walker->getListOfBonds();
@@ -132,6 +134,6 @@
       const atomId_t id = (*Runner)->GetOtherAtom(Walker)->getId();
       ASSERT(id != (size_t)-1,
-          "AdjacencyList::CreateExternalMap() - OtherAtom has not id.");
-      ExternalAtomBondMap.insert( std::make_pair(WalkerId, id) );
+          "AdjacencyList::CreateMap() - OtherAtom has not id.");
+      atombondmap.insert( std::make_pair(WalkerId, id) );
     }
   }
@@ -146,5 +148,5 @@
 
   // parse in external map
-  CreateExternalMap(atomids);
+  CreateMap(atomids, ExternalAtomBondMap);
 
   bool status = CompareInternalExternalMap();
Index: src/Graph/AdjacencyList.hpp
===================================================================
--- src/Graph/AdjacencyList.hpp	(revision 0fad93db3291c128f999fcbf427d65f1824b785b)
+++ src/Graph/AdjacencyList.hpp	(revision 5197e543aadb7e0a5343495b6e246005819cd457)
@@ -56,6 +56,6 @@
   ValuesSet getValues(const AtomBondRange&_range) const;
 
-  void CreateExternalMap(const atomids_t &atoms);
-  bool ParseInInternalMap(std::istream &File);
+  void CreateMap(const atomids_t &atoms, AtomBondMap &atombondmap);
+  bool ParseIntoMap(std::istream &File, AtomBondMap &atombondmap);
   bool CompareInternalExternalMap();
 };
Index: src/Graph/unittests/AdjacencyListUnitTest.hpp
===================================================================
--- src/Graph/unittests/AdjacencyListUnitTest.hpp	(revision 0fad93db3291c128f999fcbf427d65f1824b785b)
+++ src/Graph/unittests/AdjacencyListUnitTest.hpp	(revision 5197e543aadb7e0a5343495b6e246005819cd457)
@@ -30,6 +30,6 @@
 {
   CPPUNIT_TEST_SUITE( AdjacencyListTest );
-  CPPUNIT_TEST ( CreateExternalMapTest );
-  CPPUNIT_TEST ( ParseInInternalMapTest );
+  CPPUNIT_TEST ( CreateMapTest );
+  CPPUNIT_TEST ( ParseIntoMapTest );
   CPPUNIT_TEST ( CompareInternalExternalMapTest );
   CPPUNIT_TEST ( CheckAgainstSubsetTest );
@@ -40,6 +40,6 @@
   void tearDown();
 
-  void CreateExternalMapTest();
-  void ParseInInternalMapTest();
+  void CreateMapTest();
+  void ParseIntoMapTest();
   void CompareInternalExternalMapTest();
   void CheckAgainstSubsetTest();

Index: src/Graph/unittests/AdjacencyListUnitTest.cpp
===================================================================
--- src/Graph/unittests/AdjacencyListUnitTest.cpp	(revision 0fad93db3291c128f999fcbf427d65f1824b785b)
+++ src/Graph/unittests/AdjacencyListUnitTest.cpp	(revision 5197e543aadb7e0a5343495b6e246005819cd457)
@@ -161,12 +161,12 @@
 }
 
-/** Unit tests for AdjacencyList::CreateExternalMap().
- *
- */
-void AdjacencyListTest::CreateExternalMapTest()
+/** Unit tests for AdjacencyList::CreateMap().
+ *
+ */
+void AdjacencyListTest::CreateMapTest()
 {
   std::stringstream input;
   AdjacencyList fileChecker(input);
-  fileChecker.CreateExternalMap(atomIds);
+  fileChecker.CreateMap(atomIds, fileChecker.ExternalAtomBondMap);
 
   // check size (it's 8*2 + 2*1 = 18 keys)
@@ -190,13 +190,13 @@
 }
 
-/** Unit tests for AdjacencyList::ParseInInternalMap().
- *
- */
-void AdjacencyListTest::ParseInInternalMapTest()
+/** Unit tests for AdjacencyList::ParseIntoMap().
+ *
+ */
+void AdjacencyListTest::ParseIntoMapTest()
 {
   std::stringstream input(adjacencyfile);
   AdjacencyList fileChecker(input);
   std::vector<atomId_t> noids;
-  fileChecker.CreateExternalMap(noids);
+  fileChecker.CreateMap(noids, fileChecker.ExternalAtomBondMap);
 
   // check size (it's 8*2 + 2*1 = 18 keys)
@@ -232,5 +232,5 @@
 
   // parse in external map
-  fileChecker.CreateExternalMap(atomIds);
+  fileChecker.CreateMap(atomIds, fileChecker.ExternalAtomBondMap);
 
   // assert equality after parsing